@@ -9,7 +9,7 @@ import requests
 
 URL = 'http://loadingproductions.com'
 TEST_URL = 'http://127.0.0.1:5000'
-TEST_CLOUD_URL = 'http://3.137.160.113:5000'
+TEST_CLOUD_URL = 'http://3.137.160.113'
 
 
 def config():
@@ -29,18 +29,17 @@ def fetch_commands(url: str, interval=10, wait=5):
         res = requests.get(url)
         try:
             data = [c for c in res.json() if not c['executed']]
+            print(f"FETCHED: {len(data)}")
         except:
             print("Error: request to api crashed")
             data = []
         if len(data) == 0:
-            print("No data found...")
             sleep(wait)
             continue
         i = 0
         while i < len(data):
-            print(f"Found: {data}")
+            print(f"DATA[{i}: {min(i+interval, len(data))}]: {data}")
             yield data[i:i+interval]
-            sleep(wait)
             i += interval
 
 
@@ -105,17 +104,17 @@ def main():
         res = requests.get(URL + '/ping')
         assert res.status_code == 200, f"Url returned status code: {res.status_code}"
         assert res.json()['connection'] == "successful"
-        run(URL, interval=5)
+        run(URL, interval=10, wait=5)
     elif response == '2':
         res = requests.get(TEST_URL + '/ping')
         assert res.status_code == 200, f"Url returned status code: {res.status_code}"
         assert res.json()['connection'] == "successful"
-        run(TEST_URL, interval=5, wait=5)
+        run(TEST_URL, interval=10, wait=5)
     elif response == '3':
         res = requests.get(TEST_CLOUD_URL + '/ping')
         assert res.status_code == 200, f"Url returned status code: {res.status_code}"
         assert res.json()['connection'] == "successful"
-        run(TEST_CLOUD_URL, interval=5, wait=5)
+        run(TEST_CLOUD_URL, interval=10, wait=5)
     elif response == '4':
         presentation()
 
